@@ -40,22 +40,18 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 from logging import getLogger
-from collections import Callable
 
-from django.conf import settings
-from django.template import RequestContext
-from django.shortcuts import render_to_response
-from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpResponse
 from django.http import HttpResponseServerError
+from django.shortcuts import render_to_response
+from django.template import RequestContext
 from django.views.decorators.csrf import csrf_exempt
 
 from django_xmlrpc.decorators import xmlrpc_func
-from django_xmlrpc.dispatcher import DjangoXMLRPCDispatcher
+from django_xmlrpc.dispatcher import xmlrpc_dispatcher
 
 
-logger = getLogger('xmlrpc')
-xmlrpcdispatcher = DjangoXMLRPCDispatcher(allow_none=False, encoding=None)
+logger = getLogger('xmlrpc.views')
 
 
 @xmlrpc_func(returns='string', args=['string'])
@@ -72,71 +68,32 @@ def handle_xmlrpc(request):
         The HttpRequest object that carries the XML-RPC call. If this is a
         GET request, nothing will happen (we only accept POST requests)
     """
-    if request.method == "POST":
+    if request.method == 'POST':
         logger.info(request.body)
         try:
             response = HttpResponse(content_type='text/xml')
             response.write(
-                xmlrpcdispatcher._marshaled_dispatch(request.body))
+                xmlrpc_dispatcher._marshaled_dispatch(request.body))
             logger.debug(response)
             return response
         except:
             return HttpResponseServerError()
     else:
-        methods = xmlrpcdispatcher.system_listMethods()
+        methods = xmlrpc_dispatcher.system_listMethods()
         method_list = []
 
         for method in methods:
-            sig_ = xmlrpcdispatcher.system_methodSignature(method)
+            sig_ = xmlrpc_dispatcher.system_methodSignature(method)
             sig = {
                 'returns': sig_[0],
-                'args': ", ".join(sig_[1:]),
+                'args': ', '.join(sig_[1:]),
             }
 
-            # this just reads your docblock, so fill it in!
-            method_help = xmlrpcdispatcher.system_methodHelp(method)
+            # This just reads your docblock, so fill it in!
+            method_help = xmlrpc_dispatcher.system_methodHelp(method)
 
             method_list.append((method, sig, method_help))
 
-        return render_to_response('xmlrpc_get.html', {'methods': method_list},
-                                  context_instance=RequestContext(request))
-
-
-# Load up any methods that have been registered with the server in settings
-if hasattr(settings, 'XMLRPC_METHODS'):
-    for path, name in settings.XMLRPC_METHODS:
-        # if "path" is actually a function, just add it without fuss
-        if isinstance(path, Callable):
-            xmlrpcdispatcher.register_function(path, name)
-            continue
-
-        # Otherwise we try and find something that we can call
-        i = path.rfind('.')
-        module, attr = path[:i], path[i + 1:]
-
-        try:
-            mod = __import__(module, globals(), locals(), [attr])
-        except ImportError as ex:
-            raise ImproperlyConfigured(
-                "Error registering XML-RPC method: "
-                "module %s can't be imported" % module)
-
-        try:
-            func = getattr(mod, attr)
-        except AttributeError:
-            raise ImproperlyConfigured(
-                'Error registering XML-RPC method: '
-                'module %s doesn\'t define a method "%s"' % (module, attr))
-
-        if not isinstance(func, Callable):
-            raise ImproperlyConfigured(
-                'Error registering XML-RPC method: '
-                '"%s" is not callable in module %s' % (attr, module))
-
-        xmlrpcdispatcher.register_function(func, name)
-
-
-# Finally, register the introspection and multicall methods with the XML-RPC
-# namespace
-xmlrpcdispatcher.register_introspection_functions()
-xmlrpcdispatcher.register_multicall_functions()
+        return render_to_response(
+            'xmlrpc_get.html',
+            RequestContext(request, {'methods': method_list}))
